@@ -26,6 +26,8 @@ def register_ipython_shortcuts(registry, shell):
                                  & insert_mode
                         ))(newline_or_execute_outer(shell))
 
+    registry.add_binding(Keys.ControlBackslash)(force_exit)
+
     registry.add_binding(Keys.ControlP,
                          filter=(ViInsertMode() & HasFocus(DEFAULT_BUFFER)
                         ))(previous_history_or_previous_completion)
@@ -56,6 +58,10 @@ def register_ipython_shortcuts(registry, shell):
                                  & cursor_in_leading_ws
                         ))(indent_buffer)
 
+    registry.add_binding(Keys.ControlO,
+                         filter=(HasFocus(DEFAULT_BUFFER)
+                                & EmacsInsertMode()))(newline_with_copy_margin)
+
     if shell.display_completions == 'readlinelike':
         registry.add_binding(Keys.ControlI,
                              filter=(HasFocus(DEFAULT_BUFFER)
@@ -141,9 +147,29 @@ def reset_search_buffer(event):
 def suspend_to_bg(event):
     event.cli.suspend_to_background()
 
+def force_exit(event):
+    """
+    Force exit (with a non-zero return value)
+    """
+    sys.exit("Quit")
+
 def indent_buffer(event):
     event.current_buffer.insert_text(' ' * 4)
 
+def newline_with_copy_margin(event):
+    """
+    Preserve margin and cursor position when using
+    Control-O to insert a newline in EMACS mode
+    """
+    b = event.current_buffer
+    cursor_start_pos = b.document.cursor_position_col
+    b.newline(copy_margin=True)
+    b.cursor_up(count=1)
+    cursor_end_pos = b.document.cursor_position_col
+    if cursor_start_pos != cursor_end_pos:
+        pos_diff = cursor_start_pos - cursor_end_pos
+        b.cursor_right(count=pos_diff)
+
 
 
 
