@@ -67,7 +67,7 @@ def as_unittest(func):
 
 # Utility functions
 
-def apply_wrapper(wrapper, func):
+def apply_wrapper(wrapper,func):
     """Apply a wrapper to a function for decoration.
 
     This mixes Michele Simionato's decorator tool with nose's make_decorator,
@@ -76,14 +76,14 @@ def apply_wrapper(wrapper, func):
     This will ensure that wrapped functions can still be well introspected via
     IPython, for example.
     """
-    warnings.warn("The function `apply_wrapper` is deprecated since IPython 4.0",
-            DeprecationWarning, stacklevel=2)
+    warnings.warn("The function `apply_wrapper` is deprecated and might be removed in IPython 5.0", DeprecationWarning)
+
     import nose.tools
 
     return decorator(wrapper,nose.tools.make_decorator(func)(wrapper))
 
 
-def make_label_dec(label, ds=None):
+def make_label_dec(label,ds=None):
     """Factory function to create a decorator that applies one or more labels.
 
     Parameters
@@ -128,8 +128,7 @@ def make_label_dec(label, ds=None):
     True
     """
 
-    warnings.warn("The function `make_label_dec` is deprecated since IPython 4.0",
-            DeprecationWarning, stacklevel=2)
+    warnings.warn("The function `make_label_dec` is deprecated and might be removed in IPython 5.0", DeprecationWarning)
     if isinstance(label, string_types):
         labels = [label]
     else:
@@ -285,8 +284,7 @@ def decorated_dummy(dec, name):
     import IPython.testing.decorators as dec
     setup = dec.decorated_dummy(dec.skip_if_no_x11, __name__)
     """
-    warnings.warn("The function `decorated_dummy` is deprecated since IPython 4.0",
-        DeprecationWarning, stacklevel=2)
+    warnings.warn("The function `make_label_dec` is deprecated and might be removed in IPython 5.0", DeprecationWarning)
     dummy = lambda: None
     dummy.__name__ = name
     return dec(dummy)
@@ -319,8 +317,7 @@ skip_if_no_x11 = skipif(_x11_skip_cond, _x11_skip_msg)
 
 # not a decorator itself, returns a dummy function to be used as setup
 def skip_file_no_x11(name):
-    warnings.warn("The function `skip_file_no_x11` is deprecated since IPython 4.0",
-            DeprecationWarning, stacklevel=2)
+    warnings.warn("The function `skip_file_no_x11` is deprecated and might be removed in IPython 5.0", DeprecationWarning)
     return decorated_dummy(skip_if_no_x11, name) if _x11_skip_cond else None
 
 # Other skip decorators
@@ -375,8 +372,7 @@ def onlyif_any_cmd_exists(*commands):
     """
     Decorator to skip test unless at least one of `commands` is found.
     """
-    warnings.warn("The function `onlyif_any_cmd_exists` is deprecated since IPython 4.0",
-            DeprecationWarning, stacklevel=2)
+    warnings.warn("The function `onlyif_any_cmd_exists` is deprecated and might be removed in IPython 5.0", DeprecationWarning)
     for cmd in commands:
         if which(cmd):
             return null_deco
